const request = require('request-promise');
const cheerio = require('cheerio');

module.exports = (clientID, state, user, pass, cookieJar, proxy) => new Promise(async (resolve, reject) => {
    //Submit credentials
    try {
        const options = {
            uri: 'https://accounts.stockx.com/usernamepassword/login',
            method: 'POST',
            headers: {
                'Host': 'accounts.stockx.com',
                'sec-fetch-mode': 'cors',
                'auth0-client': clientID,
                'origin': 'https://accounts.stockx.com',
                'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/77.0.3865.120 Safari/537.36',
                'content-type': 'application/json',
                'sec-fetch-site': 'same-origin'
            },
            json: {
                client_id: clientID,
                redirect_uri: 'https://stockx.com/callback?path=/',
                tenant: 'stockx-prod',
                response_type: 'code',
                audience: 'gateway.stockx.com',
                state: state,
                _csrf: 'OnRjJjWty9Fw6jz95NFqwoPV',
                username: user,
                password: pass,
                _instate: 'deprecated',
                connection: 'production'
            },
            jar: cookieJar,
            resolveWithFullResponse: true,
            simple: false
        };

        if (proxy != '') options.proxy = proxy;

        const res = await request(options);

        if (res.statusCode == 401 && JSON.stringify(res.body).includes('Incorrect email or password')) return reject("Invalid credentials!");
        else if (res.statusCode != 200) return reject(`Status code error ${res.statusCode} - Response: ${JSON.stringify(res.body)}`);

        //Fetch params needed for callback
        const $ = cheerio.load(res.body);
        const wa = $('input[name="wa"]').val();
        const wctx = $('input[name="wctx"]').val();
        const wresult = $('input[name="wresult"]').val();

        if (wa == undefined || wctx == undefined || wresult == undefined || wa == "" || wctx == "" || wresult == "") return reject("No paramaters found for callback");

        return resolve({
            wa,
            wctx,
            wresult
        });
    }
    catch(e){
        return reject(e.message);
    };
});